summary refs log tree commit diff
path: root/pkgs/os-specific/darwin/binutils/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/os-specific/darwin/binutils/default.nix')
-rw-r--r--pkgs/os-specific/darwin/binutils/default.nix16
1 files changed, 8 insertions, 8 deletions
diff --git a/pkgs/os-specific/darwin/binutils/default.nix b/pkgs/os-specific/darwin/binutils/default.nix
index 8ac93689373..613606b5035 100644
--- a/pkgs/os-specific/darwin/binutils/default.nix
+++ b/pkgs/os-specific/darwin/binutils/default.nix
@@ -3,24 +3,24 @@
 }:
 
 # Make sure both underlying packages claim to have prepended their binaries
-# with the same prefix.
-assert binutils-raw.prefix == cctools.prefix;
+# with the same targetPrefix.
+assert binutils-raw.targetPrefix == cctools.targetPrefix;
 
 let
-  inherit (binutils-raw) prefix;
+  inherit (binutils-raw) targetPrefix;
   cmds = [
     "ar" "ranlib" "as" "dsymutil" "install_name_tool"
     "ld" "strip" "otool" "lipo" "nm" "strings" "size"
   ];
 in
 
 # TODO loop over prefixed binaries too
 stdenv.mkDerivation {
-  name = "${prefix}cctools-binutils-darwin";
+  name = "${targetPrefix}cctools-binutils-darwin";
   buildCommand = ''
     mkdir -p $out/bin $out/include
 
-    ln -s ${binutils-raw.out}/bin/${prefix}c++filt $out/bin/${prefix}c++filt
+    ln -s ${binutils-raw.out}/bin/${targetPrefix}c++filt $out/bin/${targetPrefix}c++filt
 
     # We specifically need:
     # - ld: binutils doesn't provide it on darwin
@@ -33,7 +33,7 @@ stdenv.mkDerivation {
     # - strip: the binutils one seems to break mach-o files
     # - lipo: gcc build assumes it exists
     # - nm: the gnu one doesn't understand many new load commands
-    for i in ${stdenv.lib.concatStringsSep " " (builtins.map (e: prefix + e) cmds)}; do
+    for i in ${stdenv.lib.concatStringsSep " " (builtins.map (e: targetPrefix + e) cmds)}; do
       ln -sf "${cctools}/bin/$i" "$out/bin/$i"
     done
 
@@ -44,6 +44,6 @@ stdenv.mkDerivation {
   '';
 
   passthru = {
-    inherit prefix;
+    inherit targetPrefix;
   };
 }
@@ -3,24 +3,24 @@
 in
 
-# TODO loop over prefixed binaries too
+# TODO loop over targetPrefixed binaries too
 stdenv.mkDerivation {